@@ -24,7 +24,7 @@
 #define MP4V2_PROJECT_repo_rev        493
 #define MP4V2_PROJECT_repo_date       "2012-05-20 15:16:54 -0700 (Sun, 20 May 2012)"
 #define MP4V2_PROJECT_repo_type       "stable"
-#define MP4V2_PROJECT_build           "Thu Jul  9 22:02:43 MDT 2015"
+#define MP4V2_PROJECT_build           "Thu Dec 10 21:14:08 MST 2015"
 
 /*****************************************************************************/
 
